;; Generated package description from lex.el  -*- no-byte-compile: t -*-
(define-package "lex" "1.1.0.20201201.161755" "Lexical analyser construction" 'nil :url "https://elpa.gnu.org/packages/lex.html" :authors '(("Stefan Monnier" . "monnier@iro.umontreal.ca")) :maintainer '("Stefan Monnier" . "monnier@iro.umontreal.ca"))
